==> james-project-3.7.6-source-release.zip: james-project/protocols/imap/src/main/java/org/apache/james/imap/encode/ExistsResponseEncoder.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.imap.encode;

import java.io.IOException;

import org.apache.james.imap.message.response.ExistsResponse;

public class ExistsResponseEncoder implements ImapResponseEncoder<ExistsResponse> {
    public static final String EXISTS = "EXISTS";

    @Override
    public Class<ExistsResponse> acceptableMessages() {
        return ExistsResponse.class;
    }

    @Override
    public void encode(ExistsResponse existsResponse, ImapResponseComposer composer) throws IOException {
        long numberOfMessages = existsResponse.getNumberOfMessages();
        
        composer.untagged().message(numberOfMessages).message(EXISTS).end();

    }
}

==> james-project-3.9.0-source-release.zip: james-project/protocols/imap/src/main/java/org/apache/james/imap/encode/ExistsResponseEncoder.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.imap.encode;

import static java.nio.charset.StandardCharsets.US_ASCII;

import java.io.IOException;

import org.apache.james.imap.message.response.ExistsResponse;

public class ExistsResponseEncoder implements ImapResponseEncoder<ExistsResponse> {
    public static final byte[] EXISTS = "EXISTS".getBytes(US_ASCII);

    @Override
    public Class<ExistsResponse> acceptableMessages() {
        return ExistsResponse.class;
    }

    @Override
    public void encode(ExistsResponse existsResponse, ImapResponseComposer composer) throws IOException {
        long numberOfMessages = existsResponse.getNumberOfMessages();
        
        composer.untagged().message(numberOfMessages).message(EXISTS).end();

    }
}
